# Advanced User Guide - Intro

## Additional Features

The main [Tutorial - User Guide](../tutorial/){.internal-link target=_blank} should be enough to give you a tour through all the main features of **Squall**.

In the next sections you will see other options, configurations, and additional features.

!!! tip
    The next sections are **not necessarily "advanced"**.

    And it's possible that for your use case, the solution is in one of them.

## Read the Tutorial first

You could still use most of the features in **Squall** with the knowledge from the main [Tutorial - User Guide](../tutorial/){.internal-link target=_blank}.

And the next sections assume you already read it, and assume that you know those main ideas.

## TestDriven.io course
